@@ -38,6 +38,8 @@ sub new {
     my $start = $self->start_timer;
     $self->debug("$class: parsing XML...");
 
+    eval { 
+
     if ($args{path}) { 
         $twig->parsefile($args{path});
     } elsif ($args{string}) { 
@@ -46,6 +48,12 @@ sub new {
         $twig->parse(${$args{stringref}});
     }
 
+    }; 
+
+    if ($@) { 
+        return; 
+    }
+
     my $howlong = $self->howlong($start);
     $self->debug("$class: parse complete in $howlong seconds");
 
